diff --git a/src/test/perl/PostgresNode.pm b/src/test/perl/PostgresNode.pm
index 4b225e14717c65f70369405590a3e5ed5f5bf20b..535d6c0e7cb6cffae0d29b0109d27350272dc700 100644
--- a/src/test/perl/PostgresNode.pm
+++ b/src/test/perl/PostgresNode.pm
@@ -1192,7 +1192,7 @@ sub psql
 =item $node->poll_query_until(dbname, query)
 
 Run a query once a second, until it returns 't' (i.e. SQL boolean true).
-Continues polling if psql returns an error result. Times out after 90 seconds.
+Continues polling if psql returns an error result. Times out after 180 seconds.
 
 =cut
 
@@ -1222,7 +1222,7 @@ sub poll_query_until
 		$attempts++;
 	}
 
 	# The query result didn't change in 90 seconds. Give up. Print the stderr
 	# from the last attempt, hopefully that's useful for debugging.
 	diag $stderr;
 	return 0;
@@ -1222,7 +1222,7 @@ sub poll_query_until
 	}
 
-	# The query result didn't change in 90 seconds. Give up. Print the stderr
+	# The query result didn't change in 180 seconds. Give up. Print the stderr
 	# from the last attempt, hopefully that's useful for debugging.
 	diag $stderr;